- Implemented types
-
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(dynamic value, {T orElse()?})
→ T
-
-
cast(dynamic value, {T orElse()?})
→ T
-
Casts a dynamic value to the type
T.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
tryCast(dynamic value, {T orElse()?})
→ T?
-
Tries to cast a dynamic value to the type
T.
override